diff --git a/Code/ApplicationEngine/otbWrapperApplication.h b/Code/ApplicationEngine/otbWrapperApplication.h
index 59da079f849dd2e98eebc8a230d6b57e916c3fb2..24e28a32810428dca1995f1bd536ffa91232e0b9 100644
--- a/Code/ApplicationEngine/otbWrapperApplication.h
+++ b/Code/ApplicationEngine/otbWrapperApplication.h
@@ -728,11 +728,14 @@ private:
   std::vector<std::string> m_DocTags;
 
   /**
     * Declare the class Wrapper::MapProjectionParametersHandler as friend
     * to be able to access to the protected method of
     * Wrapper::Application class.
     **/
   friend class MapProjectionParametersHandler;
+  friend class ElevationParametersHandler;
 
 }; //end class
@@ -728,11 +728,14 @@ private:
 
   /**
-    * Declare the class Wrapper::MapProjectionParametersHandler as friend
-    * to be able to access to the protected method of
+    * Declare the class
+    * - Wrapper::MapProjectionParametersHandler
+    * - Wrapper::ElevationParametersHandler
+    * as friend to be able to access to the protected method of
     * Wrapper::Application class.
     **/